@@ -771,7 +771,8 @@ TEST_CASE("Test with priority inversion") {
 
     auto high_priority_thread_func = [&] {
         // Increase external threads priority
-        utils::increase_thread_priority();
+        utils::increased_priority_guard guard{};
+        utils::suppress_unused_warning(guard);
         // pin external threads
         test_arena.execute([]{});
         while (task_counter++ < critical_task_counter) {
@@ -796,7 +797,8 @@ TEST_CASE("Test with priority inversion") {
         high_priority_threads.emplace_back(high_priority_thread_func);
     }
 
-    utils::increase_thread_priority();
+    utils::increased_priority_guard guard{};
+    utils::suppress_unused_warning(guard);
     while (task_counter++ < critical_task_counter) {
         submit(critical_task, test_arena, test_context, true);
         std::this_thread::sleep_for(std::chrono::milliseconds(1));
